

/*

   Name: ListMethodsByActivity.sql

   Description: Custom SQL Script for listing methods by activity

   This script will list all method calls and durations for each unique activity, 
   ordering the methods within the activity by begin time.

   Author: Xtremesoft Inc.
   Date: 04/01/2010

*/


SELECT 	LEFT(LTRIM(a.ActivityGuid ), 40) AS 'Activity GUID',
		--STR((o.ObjectID * 10000), 14, 0) AS 'Object Instance ID ',
		LEFT(LTRIM(m.MethodName ), 55) AS 'Method Name',
	    STR((m.EndTime - m.BeginTime), 8, 3) AS 'Duration (ms)'
	
FROM MethodObj m JOIN ObjectObj o 
	 ON m.UniqueGuid = o.UniqueGuid JOIN ActivityObj a 
	 ON o.ActivityGuid = a.ActivityGuid
WHERE o.IsFirstObject = 1
ORDER BY a.ActivityGuid, m.BeginTime, m.MethodName
GO